Changelog
=========


0.5 (2017-11-20)
----------------

- Remove useless keys from faceted query ('facet.field', 'b_size', 'b_start').
  [sgeulette]

0.4 (2016-05-23)
----------------

- Add in registry a maxresults parameter to avoid rendering viewlet when query returns too many results.
  Performance optimization.
  [sgeulette]

0.3 (2016-01-26)
----------------

- Corrected failing tests of previous release.
  [sgeulette]

0.2 (2016-01-26)
----------------

- Query can contain utf-8 chars.
  [sgeulette]

0.1 (2015-11-24)
----------------

- Initial release.
  [cedricmessiant]
